pub struct AutoExtractionEngine { /* private fields */ }Implementations
Sourceimpl AutoExtractionEngine
impl AutoExtractionEngine
pub const fn new(policy: LinkPolicy) -> Self
Sourcepub fn plan<P: ExtractionProvider>(
&self,
provider: &P,
input: &ExtractionInput,
view: &MemoryView,
) -> Result<ExtractionPlan>
pub fn plan<P: ExtractionProvider>( &self, provider: &P, input: &ExtractionInput, view: &MemoryView, ) -> Result<ExtractionPlan>
Extracts, links, and converts one source into an idempotent event plan.
Errors
Rejects invalid provider output, unsafe ambiguity, provenance mismatch, identifier collisions, and invalid temporal facts.
Sourcepub fn plan_with_linker<P: ExtractionProvider>(
&self,
provider: &P,
input: &ExtractionInput,
linker: &EntityLinker,
) -> Result<ExtractionPlan>
pub fn plan_with_linker<P: ExtractionProvider>( &self, provider: &P, input: &ExtractionInput, linker: &EntityLinker, ) -> Result<ExtractionPlan>
Uses a reusable linker for batch extraction against one projection.
Errors
Has the same validation contract as Self::plan.