pub struct InMemoryStore<E> { /* private fields */ }Trait Implementations
Sourceimpl<E: Clone> Clone for InMemoryStore<E>
impl<E: Clone> Clone for InMemoryStore<E>
Sourcefn clone(&self) -> InMemoryStore<E>
fn clone(&self) -> InMemoryStore<E>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<E: Debug> Debug for InMemoryStore<E>
impl<E: Debug> Debug for InMemoryStore<E>
Sourceimpl<E> Default for InMemoryStore<E>
impl<E> Default for InMemoryStore<E>
Sourceimpl<E: Clone> EventStore<E> for InMemoryStore<E>
impl<E: Clone> EventStore<E> for InMemoryStore<E>
Sourcefn append(
&mut self,
stream: &StreamId,
expected: ExpectedVersion,
events: &[NewEvent<E>],
) -> Result<Vec<StoredEvent<E>>>
fn append( &mut self, stream: &StreamId, expected: ExpectedVersion, events: &[NewEvent<E>], ) -> Result<Vec<StoredEvent<E>>>
Atomically appends a batch to one stream. Read more
Sourcefn append_owned(
&mut self,
stream: &StreamId,
expected: ExpectedVersion,
events: Vec<NewEvent<E>>,
) -> Result<Vec<StoredEvent<E>>>
fn append_owned( &mut self, stream: &StreamId, expected: ExpectedVersion, events: Vec<NewEvent<E>>, ) -> Result<Vec<StoredEvent<E>>>
Appends an owned batch without requiring callers to retain the inputs. Read more
Sourcefn append_owned_receipt(
&mut self,
stream: &StreamId,
expected: ExpectedVersion,
events: Vec<NewEvent<E>>,
) -> Result<AppendReceipt>
fn append_owned_receipt( &mut self, stream: &StreamId, expected: ExpectedVersion, events: Vec<NewEvent<E>>, ) -> Result<AppendReceipt>
Appends an owned batch and returns positions without cloning committed
payloads back to the caller. Read more
fn load_stream( &self, stream: &StreamId, after: Option<u64>, ) -> Vec<StoredEvent<E>>
fn load_all(&self, after: Option<u64>, limit: usize) -> Vec<StoredEvent<E>>
fn stream_version(&self, stream: &StreamId) -> Option<u64>
fn len(&self) -> usize
fn is_empty(&self) -> bool